aerosoltools.aerosol2d.Aerosol2D.timecrop — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.timecrop

Aerosol2D.timecrop(start=None, end=None, inplace=True)

  Crop the data to a specified time window.

  ## Parameters

  startstr or pd.Timestamp, optional

    Start time. If None, cropping starts from the earliest available time. If a string, it should have the format “YYYY-MM-DD HH:MM:SS”, e.g., “2025-01-24 20:00:00”.

  endstr or pd.Timestamp, optional

    End time. If None, cropping ends at the latest available time. If a string, it should have the format “YYYY-MM-DD HH:MM:SS”, e.g., “2025-01-25 20:00:00”.

  inplacebool, optional

    If True, modifies the current object. If False, returns a new cropped instance. Defaults to True.

  ## Returns

  Aerosol1D

    Instance of Aerosol1D. Either the modified current object (if inplace=True) or a new cropped object (if inplace=False).

  Parameters:

    - start (str | Timestamp | None)

    - end (str | Timestamp | None)

    - inplace (bool)

  Return type:

    Aerosol1D